#
# spec file for package synapse
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           synapse
Version:        0.2.99.4
Release:        lp152.3.9
Summary:        A semantic launcher for GNOME
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://launchpad.net/synapse-project
Source:         https://launchpad.net/synapse-project/0.3/%{version}/+download/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.14.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.0.0
BuildRequires:  pkgconfig(gee-0.8) >= 0.5.2
BuildRequires:  pkgconfig(glib-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkhotkey-1.0)
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.10.0
BuildRequires:  pkgconfig(keybinder-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(rest-0.7)
BuildRequires:  pkgconfig(zeitgeist-2.0)
Recommends:     %{name}-lang

%description
Synapse is a semantic launcher written in Vala that you can use to start
applications as well as find and access relevant documents and files by
making use of the Zeitgeist engine.

%lang_package

%prep
%autosetup

%build
%configure \
	--disable-static \
	%{nil}
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}
%suse_update_desktop_file %{name} X-SuSE-DesktopUtility

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%license COPYING COPYING.GPL2
%doc AUTHORS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon May  7 2018 luc14n0@linuxmail.org
- Update to version 0.2.99.4:
  + Plugins: Avoid ownership mismatches of container elements.
  + Core: Use x-terminal-emulator directly on non-GNOME sessions.
- Drop intltool BuildRequires to follow upstream migration to
  Gettext.
- Append GPL-2.0-or-later to the License tag to comply with due
  source code licenses.
* Fri Mar  9 2018 bjorn.lie@gmail.com
- Update to version 0.2.99.3:
  + Bugs fixed: lp#1219314, lp#1554618, lp#1570442, lp#1637777,
    lp#1080755, lp#1504433, lp#1738964.
- Drop synapse-0.2.99.2-fix-nonmatching-generic-types.patch: Fixed
  upstream.
- Clean up spec via spec-cleaner, use autosetup macro,
  conditionally run post(un) for older versions of openSUSE only.
* Sat Apr  1 2017 sor.alexei@meowr.ru
- Add synapse-0.2.99.2-fix-nonmatching-generic-types.patch: Fix
  non-matching generic types
* Sat Sep 10 2016 zaitor@opensuse.org
- Update to version 0.2.99.2:
  + Bugs fixed: lp#1517413, lp#1489615, lp#1516295, lp#695437,
    lp#882515, lp#827858, lp#888776, lp#1475515, lp#1504504.
* Sat Jan 31 2015 sfalken@opensuse.org
- Update to 0.2.99.1
  + Build system fixes.
  + desktop-file-service: Fix typos in get_environment_type().
  + volume-service: Avoid dead-lock.
  + Also check for "chromium-browser".
  + Move tile-view into ui.
  + Add ActionMatch class and make use of it.
  + Commonize formatting of lambda-expressions.
  + Fix format of property definitions.
  + Rename DesktopFileInfo.EnvironmentType to
    DesktopEnvironmentType.
  + Fix issues with colors.
  + Added AsyncOnce.
  + Use GLib.KeyFileDesktop constants.
  + Rename Match.Score to MatchScore.
  + Rename BaseAction to Action.
  + Make Synapse.Match a GObject to be able subclass it properly.
  + Match.mime_type is not allowed to be null, fixes critical.
  + Actually use "activate" shortcut from config.
  + Add support for newly registered desktop environments and
    "Pantheon".
  + core: Mark Utils.extract_type_name static, Utils is just a
    namespace.
  + match: Don't allow null to be passed as argument in execute().
  + match: Make it possible to ApplicationMatch and UriMatch
    directly.
  + opensearch: add DuckDuckGo support.
  + plugins: Add simple GNOME bookmarks support.
  + plugins: Add "Remove" action.
  + plugins: Fix launching applications.
  + plugins: Update for Rythmbox 3.
  + plugins: Properly handle of some Match objects.
  + plugins: Use unicode-safe char_count() instead of length.
  + plugins: Drop useless subclasses of UriMatch.
  + plugins: Add systemd/logind support.
  + ui: Drop unused Inspector.
- Adjust BuildRequires for full GNOME 3 port:
  - Dropped pkgconfig(zeitgeist-1.0), pkgconfig(gee-1.0),
    pkgconfig(gtk+-2.0), pkgconfig(unique-1.0).
  - Added pkgconfig(zeitgeist-2.0), pkgconfig(ee-0.8),
    pkgconfig(gtk+-3.0), pkgconfig(gdk-x11-3.0),
    pkgconfig(keybinder-3.0).
- Dropped upstream fixed patches:
  + synapse-gnome-3.10.patch
  + synapse-fix-border-painting.patch
* Tue Sep  3 2013 dimstar@opensuse.org
- Add synapse-gnome-3.10.patch: Explicitly choose Gtk.Timeout to
  fix build.
* Fri Nov 30 2012 dvaleev@suse.com
- Add synapse-fix-border-painting.patch: fix border painting
  (bnc#792215).
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 0.2.10:
  + Fixes for Suspend and Hibernate.
  + Support for Unity and LXDE.
  + Add plugin for Xnoise media player.
  + Improvements to ssh plugin.
  + Several bug fixes.
  + Build with vala >= 0.14.
- Always use vala BuildRequires (instead of vala-0_12 on 12.1 and
  later): we always need vala 0.14 now.
- Remove pkgconfig(dbus-glib-1) BuildRequires: the dependency is
  gone now.
* Mon Nov  7 2011 dimstar@opensuse.org
- Update to version 0.2.8.2:
  + Add support for Unity desktop environment (lp#885550)
  + 0.2.8.1 tarball contains no translation (lp#862104)
- Drop synapse-0.2.8.1.patch: fixed upstream.
- Remove now unneeded call to autoreconf: it was only needed for
  the patch above.
* Wed Sep 28 2011 vuntz@opensuse.org
- Note that we can't update to the 0.2.8.1 tarball since it is
  broken (lp#862104).
- Cherry-pick changes from version 0.2.8.1 in
  synapse-0.2.8.1.patch:
  + Initialize libnotify.
  + Fix potentitial crash.
- Change vala BuildRequires to vala-0_12 on 12.1 and later: synapse
  only builds with vala 0.12 for now.
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 0.2.8:
  + Various bug fixes.
  + Updated translations.
- Drop synapse.1 source: the man page is now shipped in the
  tarball.
* Sat Jun 25 2011 nmarques@opensuse.org
- Initial package from release 0.2.6.
